@@ -2,4 +2,5 @@ from .base import BaseAnalyser  # noqa
 from .mysql import MySqlAnalyser  # noqa
 from .postgresql import PostgresqlAnalyser  # noqa
 from .sqlite import SqliteAnalyser  # noqa
-from .analyser import analyse_sql_statements  # noqa
+
+from .analyser import analyse_sql_statements  # noqa isort:skip
